const env = (import.meta as unknown as {
  env: {
    DEV: boolean
    SSR: boolean
  }
}).env

export async function directus<T>(
  path: string,
  method: string = "GET",
  body: string | null = null,
): Promise<T> {
  return await fetch(
    env.DEV && !env.SSR
      ? `/test/${path.split("/").at(-1)}`
      : `https://directus.swablab.de/${path}`,
    {
      method,
      credentials: "include",
      headers: {
        "Content-Type": "application/json",
      },
      body,
    },
  )
    .then((res) => res.json())
    .then((res) => {
      if (res.errors) throw res.errors[0].message
      return res.data
    })
}

export function formatDate(
  date: string | number | Date | undefined,
  style: "short" | "medium" | "long",
) {
  if (date == null) return ""
  return Intl.DateTimeFormat("de-DE", {
    dateStyle: style,
  }).format(new Date(date))
}

export function formatTime(date: string | number | Date | undefined) {
  if (date == null) return ""
  return Intl.DateTimeFormat("de-DE", {
    timeStyle: "short",
  }).format(new Date(date))
}

export const documents = {
  "3DDruckAGB": "/docs/3d-druck-agb.pdf",
  Beitragsordnung: "/docs/beitragsordnung.pdf",
  Beleg: "/docs/beleg.pdf",
  Datenschutzhinweise: "/docs/datenschutz.pdf",
  Haftungsausschluss: "/docs/haftungsausschluss.pdf",
  Mitgliedsantrag: "/docs/mitgliedsantrag.pdf",
  Satzung: "/docs/satzung.pdf",
  "Werkstatt-AGB": "/docs/werkstatt-agb.pdf",
  "Werkstatt-Regeln": "/docs/werkstatt-regeln.pdf",
}

export type Task = {
  id: string | undefined
  title: string
  status: string
  date_due?: string
  priority: string
  description: string
  responsibles: {
    directus_users_id: {
      id: string
      first_name: string
    }
  }[]
}
